@@ -4,10 +4,9 @@ from flask import Blueprint, Flask
 
 from guniflask.config.app_settings import Settings
 from guniflask.config.env import app_name_from_env
-from guniflask.config.loader import load_app_settings
+from guniflask.config.load_utils import load_app_settings
 from guniflask.security_config.authentication_config import AuthenticationConfiguration
 from guniflask.security_config.web_security_config import WebSecurityConfiguration
-from guniflask.service_discovery.config import ServiceDiscoveryConfiguration
 from guniflask.utils.path import walk_modules
 from guniflask.web.context import WebApplicationContext
 from guniflask.web.scheduling_config import WebAsyncConfiguration, WebSchedulingConfiguration
@@ -19,8 +18,9 @@ class AppInitializer:
         app_settings = load_app_settings(self.name)
         self.settings = Settings(app_settings)
 
-    def init(self, with_context=True):
-        app = Flask(self.name)
+    def init(self, app=None, with_context=True):
+        if app is None:
+            app = Flask(self.name)
         self._make_settings(app)
         if with_context:
             self._create_bean_context(app)
@@ -59,7 +59,6 @@ class AppInitializer:
         bean_context.register(WebSecurityConfiguration)
         bean_context.register(WebAsyncConfiguration)
         bean_context.register(WebSchedulingConfiguration)
-        bean_context.register(ServiceDiscoveryConfiguration)
 
     def _refresh_bean_context(self, app):
         if hasattr(app, 'bean_context'):
