@@ -1,4 +1,4 @@
-from guniflask.orm.model_utils import model_to_dict, dict_to_model, update_model_by_dict, result_to_dict
+from guniflask.orm.model_utils import model_to_dict, dict_to_model, update_model_by_dict
 
 
 def wrap_sqlalchemy_model(model_cls):
