@@ -1,6 +1,7 @@
 import datetime as dt
 import uuid
 
+from guniflask.security import Authentication
 from guniflask.security.authentication_manager import AuthenticationManager
 from guniflask.security.authentication_token import UserAuthentication
 from guniflask.security.errors import InvalidTokenError
@@ -13,10 +14,10 @@ class JwtManager(AuthenticationManager):
     JTI = 'jti'
     AUTHORITIES = 'authorities'
     USERNAME = 'username'
-    USER_DETAILS = 'user_details'
+    USERINFO = 'userinfo'
 
-    def __init__(self, secret='', public_key=None, private_key=None, algorithm='HS256',
-                 access_token_expires_in=24 * 60 * 60, refresh_token_expires_in=365 * 24 * 60 * 60):
+    def __init__(self, secret='', public_key=None, private_key=None, algorithm=None,
+                 access_token_expires_in=12 * 60 * 60, refresh_token_expires_in=30 * 24 * 60 * 60):
         self.secret = secret
         self.public_key = public_key
         self.private_key = private_key
@@ -24,7 +25,7 @@ class JwtManager(AuthenticationManager):
         self.access_token_expires_in = access_token_expires_in
         self.refresh_token_expires_in = refresh_token_expires_in
 
-    def create_access_token(self, authorities=None, username=None, **user_details) -> str:
+    def create_access_token(self, authorities=None, username=None, **userinfo) -> str:
         expires_in = self.access_token_expires_in
         payload = {
             self.JTI: uuid.uuid4().hex
@@ -34,28 +35,35 @@ class JwtManager(AuthenticationManager):
 
         payload[self.AUTHORITIES] = authorities
         payload[self.USERNAME] = username
-        payload[self.USER_DETAILS] = user_details
+        payload[self.USERINFO] = userinfo
 
-        return JwtHelper.encode_jwt(payload, self.secret or self.private_key,
-                                    self.algorithm)
+        return JwtHelper.encode_jwt(
+            payload,
+            self.secret or self.private_key,
+            algorithm=self.algorithm,
+        )
 
-    def authenticate(self, authentication):
+    def authenticate(self, authentication: Authentication):
         access_token_value = authentication.principal
         payload = self._decode(access_token_value)
-        authorities = payload[self.AUTHORITIES]
-        username = payload[self.USERNAME]
-        user_details = payload[self.USER_DETAILS]
+        authorities = payload.get(self.AUTHORITIES)
+        username = payload.get(self.USERNAME)
+        userinfo = payload.get(self.USERINFO)
         user = User(username=username, authorities=authorities)
-        for k, v in user_details.items():
-            setattr(user, k, v)
+        if userinfo and isinstance(userinfo, dict):
+            for k, v in userinfo.items():
+                setattr(user, k, v)
         user_auth = UserAuthentication(user, authorities=authorities)
         user_auth.authenticate(True)
         return user_auth
 
     def _decode(self, access_token_value):
         try:
-            payload = JwtHelper.decode_jwt(access_token_value, self.secret or self.public_key,
-                                           self.algorithm)
+            payload = JwtHelper.decode_jwt(
+                access_token_value,
+                self.secret or self.public_key,
+                algorithms=[self.algorithm] if self.algorithm else None,
+            )
         except Exception as e:
             raise InvalidTokenError(e)
         return payload
